random_u64_range

Function random_u64_range 

pub fn random_u64_range(rng: &mut impl Rng, range: impl RangeBounds<u64>) -> u64
Sample a random number in range using rng as generator for random u64 numbers

This utility exists only to provide compatibility of sampling algorithm with rand library at versions <=0.8.5, it is equivalent to its rng.gen_range(range).

Panics: when range is empty.