WeightedU64Index

Struct WeightedU64Index 

pub struct WeightedU64Index { /* private fields */ }
Compatibility weighted sampler for u64 numbers

Sampler uses provided rand::Rng reference to generate random u64 numbers and map them to the index of the weight from weights vector provided on initialization.

This utility exists only to provide compatibility of sampling algorithm with rand library at versions <=0.8.5, since parts of the system rely on reproducible sequence of numbers given stable seeded random number generator.

The algorithm reproduces indices returned by rand::distributions::WeightedIndex for the same weights vector and seeded random number generator.

Implementations

Source

impl WeightedU64Index

pub fn new(weights: Vec<u64>) -> Result<Self, Error>

pub fn sample(&self, rng: &mut impl Rng) -> usize